import { type RefCallback } from "react";
import { type DropdownOptions } from "#/useDropdown/index.js";
export type UseTooltipOptionsTooltip = DropdownOptions & {
    /**
     * A tooltip can take on 1 of 2 forms:
     *
     * ## Form 1: A simple label
     *
     * Tooltip exists as a label that describes a control. It is intended
     * to be a simple description of the control that otherwise would have
     * a visible label but otherwise is hidden due to design or space.
     * @example "Notifications"
     *
     * ## Form 2: A clarification
     *
     * Tooltip exists as an extra clarification for a control. Provides
     * supplementary descriptions or text to better guide the user
     * on how to do something with a particular control
     * @example "View notifications and manage settings"
     */
    dxType: "tooltip";
    /**
     * This is an accessibility control that helps further context
     * what the screen reader is going to interpret. This field can be many node
     * IDs delimited by a space which should be read semantically by the screen reader.
     *
     * Let's say that there is a tooltip that has "Likes" as it's content
     * but it also has a bubble or a burst icon inside of it that details how
     * many likes there are. In this case, we need to supply another id that _labels_
     * the tooltip; let's call it "likes-count". In order for screen readers to
     * appropriately read the tooltip and the context, it needs to understand
     * which nodes with IDs label the focusable element.
     *
     * In this case we would put `likes-count likes-label` where the screen reader
     * would read "3 Likes"
     *
     * @default `the auto generated id of the dropdown ref`
     */
    dxLabeledBy?: string;
};
export type UseTooltipOptionsToggleTip = DropdownOptions & {
    dxType: "toggletip";
};
export type UseTooltipOptions = UseTooltipOptionsTooltip | UseTooltipOptionsToggleTip;
export declare const useDropdownTooltip: <DropdownNode extends HTMLElement, TargetNode extends HTMLButtonElement | HTMLAnchorElement | HTMLInputElement>(options: UseTooltipOptions) => {
    setTargetRef: RefCallback<TargetNode>;
    setTooltipRef: RefCallback<DropdownNode>;
    tooltipRef: import("react").RefObject<DropdownNode | null>;
    targetRef: import("react").RefObject<TargetNode | null>;
};
//# sourceMappingURL=useDropdownTooltip.d.ts.map