import type { ForwardedRef } from "react";
/**
 * A custom hook that manages an internal ref and forwards it to a parent component.
 *
 * This hook creates a ref that can be used internally within a component while also allowing
 * a parent component to access the current value of the ref via a forwarded reference.
 *
 * @example
 * const MyComponent = forwardRef((props, ref) => {
 *   const internalRef = useForwardedRef(ref);
 *
 *   return <input ref={internalRef} />;
 * });
 */
export declare function useForwardedRef<T extends HTMLElement>(forwardedRef: ForwardedRef<T>): import("react").RefObject<T | null>;
//# sourceMappingURL=useForwardedRef.d.ts.map