/**
 * A custom React hook for managing window event listeners.
 *
 * This hook provides two functions: `addWindowEventListener` and `removeWindowEventListener`.
 * The `addWindowEventListener` function allows you to register event listeners for various
 * window events, while the `removeWindowEventListener` function can be used to remove
 * those listeners when they are no longer needed.
 *
 * @example
 * const { addWindowEventListener, removeWindowEventListener } = useWindowEventListener();
 *
 * useEffect(() => {
 *   const handleScroll = (event) => {
 *     console.log('Scrolled!', event);
 *   };
 *
 *   // Add the scroll event listener
 *   addWindowEventListener('scroll', handleScroll);
 *
 *   // Cleanup function to remove the listener on component unmount
 *   return () => {
 *     removeWindowEventListener('scroll');
 *   };
 * }, [addWindowEventListener, removeWindowEventListener]);
 */
export declare function useWindowEventListener(): {
    addWindowEventListener: <K extends keyof WindowEventMap>(type: K, listener: (this: Window, ev: WindowEventMap[K]) => unknown, options?: boolean | AddEventListenerOptions) => void;
    removeWindowEventListener: (eventName: keyof WindowEventMap) => void;
};
//# sourceMappingURL=useWindowEventListener.d.ts.map